==> scorched3d_38.1.orig.tar.gz: scorched3d-38.1/src/actions/SoundAction.cpp <==
////////////////////////////////////////////////////////////////////////////////
//    Scorched3D (c) 2000-2004
//
//    This file is part of Scorched3D.
//
//    Scorched3D is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    Scorched3D is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Scorched3D; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////

#include <actions/SoundAction.h>
#include <weapons/WeaponSound.h>
#include <weapons/AccessoryStore.h>
#include <common/SoundStore.h>

REGISTER_ACTION_SOURCE(SoundAction);

SoundAction::SoundAction(WeaponSound *weapon) :
	weapon_(weapon)
{

}

SoundAction::~SoundAction()
{
}

void SoundAction::init()
{
}

void SoundAction::simulate(float frameTime, bool &remove)
{
	if (!context_->serverMode)
	{
		SoundBuffer *activateSound = 
			SoundStore::instance()->fetchOrCreateBuffer((char *)
				getDataFile(weapon_->getSound()));
		activateSound->play();
	}

	remove = true;
	Action::simulate(frameTime, remove);
}

bool SoundAction::writeAction(NetBuffer &buffer)
{
	context_->accessoryStore->writeWeapon(buffer, weapon_);
	return true;
}

bool SoundAction::readAction(NetBufferReader &reader)
{
	weapon_ = (WeaponSound *) context_->accessoryStore->readWeapon(reader); if (!weapon_) return false;
	return true;
}

==> scorched3d_41.2dfsg.orig.tar.gz: scorched3d-41.2dfsg/src/actions/SoundAction.cpp <==
////////////////////////////////////////////////////////////////////////////////
//    Scorched3D (c) 2000-2004
//
//    This file is part of Scorched3D.
//
//    Scorched3D is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    Scorched3D is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Scorched3D; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////

#include <actions/SoundAction.h>
#include <weapons/WeaponSound.h>
#include <weapons/AccessoryStore.h>
#include <sound/SoundUtils.h>
#include <common/Defines.h>

SoundAction::SoundAction(FixedVector &position, WeaponSound *weapon) :
	ActionReferenced("SoundAction"),
	weapon_(weapon), position_(position)
{

}

SoundAction::~SoundAction()
{
}

void SoundAction::init()
{
}

void SoundAction::simulate(fixed frameTime, bool &remove)
{
#ifndef S3D_SERVER
	if (!context_->serverMode)
	{
		SoundBuffer *activateSound = 
			Sound::instance()->fetchOrCreateBuffer((char *)
				getDataFile(weapon_->getSound()));

		VirtualSoundSource *source = new VirtualSoundSource(
			VirtualSoundPriority::eAction, false, true);
		if (weapon_->getRelative())	source->setRelative();
		else source->setPosition(position_.asVector());
		source->setGain(weapon_->getGain().asFloat());
		source->setReferenceDistance(weapon_->getReferenceDistance().asFloat());
		source->setRolloff(weapon_->getRolloff().asFloat());
		source->play(activateSound);
	}
#endif // #ifndef S3D_SERVER

	remove = true;
	Action::simulate(frameTime, remove);
}

const char *SoundAction::getActionDetails()
{
	return weapon_->getParent()->getName();
}
